@@ -11,7 +11,7 @@ __all__ = ('Problem',)
 
 fixedpoint_solvers = [wegstein, aitken]
 
-class Problem:
+class Problem: # pragma: no cover
     __slots__ = ('f', 'cases')
     
     def __init__(self, f, cases):
@@ -22,18 +22,20 @@ class Problem:
     def name(self):
         return self.f.__name__.capitalize().replace('_', ' ')
         
-    def test(self, x, tol, args): 
+    def test(self, x, tol, args=()): 
         assert abs(self.f(x, *args)) <= tol, "result not within tolerance"
         
-    def f_fixed_point(self, x, *args):
+    def f_fixedpoint(self, x, *args):
         return self.f(x, *args) + x
-        
+    
     def profile_solver(self, solver, ytol, kwargs={}):
-        f = self.f_fixed_point if solver in fixedpoint_solvers else self.f
+        isfixedpoint = solver in fixedpoint_solvers
+        f = self.f_fixedpoint if isfixedpoint else self.f
         p = Profiler(f)
         for case in self.cases:
+            if isfixedpoint: case = f(case) - case
             try: 
-                x = solver(p, 0., **kwargs)
+                x = solver(p, case, **kwargs)
                 self.test(x, ytol, kwargs.get('args', ()))
             except: 
                 p.archive_case(case, failed=True)
